@@ -30,6 +30,7 @@ import random
 
 from requests.exceptions import RequestException, ProxyError
 from .utils import HttpError, is_retriable
+from . import __version__ as version
 
 logger = logging.getLogger(__name__)
 
@@ -89,6 +90,15 @@ def quote_plus(s):
     return s
 
 
+def norm_path(path):
+    """
+    Canonicalize path to '{bucket}/{name}' form.
+
+    Used by petastorm, do not remove.
+    """
+    return "/".join(GCSFileSystem.split_path(path))
+
+
 def validate_response(r, path):
     """
     Check the requests object r, raise error if it's not ok.
@@ -314,13 +324,15 @@ class GCSFileSystem(fsspec.AbstractFileSystem):
             )
         except:  # noqa: E722
             # TODO: catch specific exceptions
+            # According https://github.com/googleapis/python-cloud-core/blob/master/google/cloud/client.py
+            # Scopes required for authenticating with a service. User authentification fails
+            # with invalid_scope if scope is specified.
             token = Credentials(
                 None,
                 refresh_token=token["refresh_token"],
                 client_secret=token["client_secret"],
                 client_id=token["client_id"],
-                token_uri="https://www.googleapis.com/oauth2/v4/token",
-                scopes=[self.scope],
+                token_uri="https://oauth2.googleapis.com/token",
             )
         return token
 
@@ -440,6 +452,11 @@ class GCSFileSystem(fsspec.AbstractFileSystem):
         data = kwargs.pop("data", None)
         r = None
 
+        if headers is None:
+            headers = {}
+        if "User-Agent" not in headers:
+            headers["User-Agent"] = "python-gcsfs/" + version
+
         if not path.startswith("http"):
             path = self.base + path
 
