@@ -32,6 +32,7 @@ from gcsfs.tests.utils import (
     tmpfile,
 )
 from gcsfs.core import GCSFileSystem, quote_plus, validate_response
+from gcsfs import __version__ as version
 
 pytestmark = pytest.mark.usefixtures("token_restore")
 
@@ -702,12 +703,12 @@ def test_writable():
 def test_merge():
     with gcs_maker() as gcs:
         with gcs.open(a, "wb") as f:
-            f.write(b"a" * 100)
+            f.write(b"a" * 10)
 
         with gcs.open(b, "wb") as f:
-            f.write(b"a" * 100)
+            f.write(b"a" * 10)
         gcs.merge(TEST_BUCKET + "/joined", [a, b])
-        assert gcs.info(TEST_BUCKET + "/joined")["size"] == 200
+        assert gcs.info(TEST_BUCKET + "/joined")["size"] == 20
 
 
 @my_vcr.use_cassette(match=["all"])
@@ -811,6 +812,22 @@ def test_request_user_project_string():
         assert result["userProject"] == [TEST_PROJECT]
 
 
+@my_vcr.use_cassette(match=["all"])
+def test_request_header():
+    with gcs_maker():
+        gcs = GCSFileSystem(TEST_PROJECT, token=GOOGLE_TOKEN, requester_pays=True)
+        # test directly against `_call` to inspect the result
+        r = gcs._call(
+            "GET",
+            "b/{}/o/",
+            TEST_REQUESTER_PAYS_BUCKET,
+            delimiter="/",
+            prefix="test",
+            maxResults=100,
+        )
+        assert r.request.headers["User-Agent"] == "python-gcsfs/" + version
+
+
 @mock.patch("gcsfs.core.gauth")
 def test_user_project_fallback_google_default(mock_auth):
     mock_auth.default.return_value = (requests.Session(), "my_default_project")
